pub struct ContentTypes {
pub defaults: HashMap<String, String>,
pub overrides: HashMap<String, String>,
}Expand description
Parsed [Content_Types].xml.
Fields
defaults: HashMap<String, String>overrides: HashMap<String, String>Implementations
Sourceimpl ContentTypes
impl ContentTypes
Sourcepub fn content_type_for(&self, part_name: &str) -> Option<&str>
pub fn content_type_for(&self, part_name: &str) -> Option<&str>
Look up the content type for a given part name.
Sourcepub fn add_default(&mut self, extension: &str, content_type: &str)
pub fn add_default(&mut self, extension: &str, content_type: &str)
Add a default content type for an extension (e.g., “png” -> “image/png”).
Sourcepub fn add_override(&mut self, part_name: &str, content_type: &str)
pub fn add_override(&mut self, part_name: &str, content_type: &str)
Add an override content type for a specific part name.
Sourcepub fn minimal() -> ContentTypes
pub fn minimal() -> ContentTypes
Create the minimal content types shared by every OPC package.